@@ -19,6 +19,9 @@ ALL_CIPHERS = (
     'AES-256-CTR', 'AES-256-CBC',
     'AES-192-CTR', 'AES-192-CBC',
     'AES-128-CTR', 'AES-128-CBC',
+    'AES-256-OCB', 'AES-256-EAX',
+    'AES-192-OCB', 'AES-192-EAX',
+    'AES-128-OCB', 'AES-128-EAX',
     'CAMELLIA-256-CBC', 'CAMELLIA-192-CBC', 'CAMELLIA-128-CBC',
     '3DES-CBC', 'DES-CBC', 'RC4-40', 'RC4-128',
     'DES40-CBC', 'RC2-CBC', 'IDEA-CBC', 'SEED-CBC',
@@ -61,7 +64,7 @@ EXPERIMENTAL_GROUPS = (
     'P521-MLKEM1024',
 )
 ALL_GROUPS = (
-    'X25519-MLKEM768', 'P256-MLKEM768', 'P384-MLKEM1024', 'MLKEM768-X25519',
+    'MLKEM768-X25519', 'P256-MLKEM768', 'P384-MLKEM1024', 'MLKEM1024-X448',
     'X25519', 'SECP256R1', 'SECP384R1', 'SECP521R1', 'X448',
     'FFDHE-1536', 'FFDHE-2048', 'FFDHE-3072', 'FFDHE-4096',
     'FFDHE-6144', 'FFDHE-8192', 'FFDHE-1024',
@@ -75,8 +78,8 @@ EXPERIMENTAL_SIGN = (
     'P256-MLDSA44', 'RSA3072-MLDSA44', 'MLDSA44-PSS2048', 'MLDSA44-RSA2048',
     'MLDSA44-ED25519', 'MLDSA44-P256', 'MLDSA44-BP256',
     'P384-MLDSA65', 'MLDSA65-PSS3072', 'MLDSA65-RSA3072',
-    'MLDSA65-P256', 'MLDSA65-BP256', 'MLDSA65-ED25519',
-    'P521-MLDSA87', 'MLDSA87-P384', 'MLDSA87-BP384', 'MLDSA87-ED448',
+    'MLDSA65-P256', 'MLDSA65-BP256',
+    'P521-MLDSA87', 'MLDSA87-P384', 'MLDSA87-BP384',
     # no FALCON, only FN-DSA
     # 'FALCON512',
     # 'P256-FALCON512', 'RSA3072-FALCON512',
@@ -97,7 +100,7 @@ EXPERIMENTAL_SIGN = (
     # 'P256-SPHINCSSHAKE128FSIMPLE', 'RSA3072-SPHINCSSHAKE128FSIMPLE',
 )
 ALL_SIGN = (
-    'MLDSA44', 'MLDSA65', 'MLDSA87',
+    'MLDSA44', 'MLDSA65', 'MLDSA87', 'MLDSA65-ED25519', 'MLDSA87-ED448',
     'RSA-MD5', 'RSA-SHA1', 'DSA-SHA1', 'ECDSA-SHA1',
     'RSA-SHA2-224', 'DSA-SHA2-224', 'ECDSA-SHA2-224',
     'RSA-SHA2-256', 'DSA-SHA2-256', 'ECDSA-SHA2-256',
